@@ -72,7 +72,7 @@ class AdaptationOffer(HasTraits):
     def _get_to_protocol_name(self):
         return self._get_type_name(self._to_protocol)
 
-    #### Private protocol ######################################################
+    #### Private protocol #####################################################
 
     #: Shadow trait for the corresponding property.
     _factory = Any
@@ -94,8 +94,6 @@ class AdaptationOffer(HasTraits):
 
         self._factory = factory
 
-        return
-
     #: Shadow trait for the corresponding property.
     _from_protocol = Any
     _from_protocol_loaded = Bool(False)
@@ -116,8 +114,6 @@ class AdaptationOffer(HasTraits):
 
         self._from_protocol = from_protocol
 
-        return
-
     #: Shadow trait for the corresponding property.
     _to_protocol = Any
     _to_protocol_loaded = Bool(False)
@@ -138,8 +134,6 @@ class AdaptationOffer(HasTraits):
 
         self._to_protocol = to_protocol
 
-        return
-
     def _get_type_name(self, type_or_type_name):
         """ Returns the full dotted path for a type.
 
