@@ -20,13 +20,16 @@ from traits.api import (
     CFloat,
     CInt,
     ComparisonMode,
+    Color,
     Delegate,
     Float,
+    Font,
     HasTraits,
     Instance,
     Int,
     List,
     Range,
+    RGBColor,
     Str,
     This,
     Trait,
@@ -38,6 +41,7 @@ from traits.api import (
     pop_exception_handler,
     push_exception_handler,
 )
+from traits.testing.optional_dependencies import requires_traitsui
 
 #  Base unit test classes:
 
@@ -471,8 +475,12 @@ class EnumTest(AnyTraitTest):
     _bad_values = [0, "zero", 4, None]
 
 
-class MappedTrait(HasTraits):
-    value = Trait("one", {"one": 1, "two": 2, "three": 3})
+# Suppress DeprecationWarning from (implicit) TraitMap instantiation
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class MappedTrait(HasTraits):
+        value = Trait("one", {"one": 1, "two": 2, "three": 3})
 
 
 class MappedTest(AnyTraitTest):
@@ -485,8 +493,12 @@ class MappedTest(AnyTraitTest):
     _bad_values = ["four", 1, 2, 3, [1], (1,), {1: 1}, None]
 
 
-class PrefixListTrait(HasTraits):
-    value = Trait("one", TraitPrefixList("one", "two", "three"))
+# Suppress DeprecationWarning from TraitPrefixList instantiation.
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class PrefixListTrait(HasTraits):
+        value = Trait("one", TraitPrefixList("one", "two", "three"))
 
 
 class PrefixListTest(AnyTraitTest):
@@ -511,8 +523,12 @@ class PrefixListTest(AnyTraitTest):
         return {"o": "one", "on": "one", "tw": "two", "th": "three"}[value[:2]]
 
 
-class PrefixMapTrait(HasTraits):
-    value = Trait("one", TraitPrefixMap({"one": 1, "two": 2, "three": 3}))
+# Suppress DeprecationWarning from TraitPrefixMap instantiation.
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class PrefixMapTrait(HasTraits):
+        value = Trait("one", TraitPrefixMap({"one": 1, "two": 2, "three": 3}))
 
 
 class PrefixMapTest(AnyTraitTest):
@@ -933,20 +949,26 @@ except AttributeError:
     pass
 
 
-class complex_value(HasTraits):
-    num1 = Trait(1, Range(1, 5), Range(-5, -1))
-    num2 = Trait(
-        1,
-        Range(1, 5),
-        TraitPrefixList("one", "two", "three", "four", "five"),
-    )
-    num3 = Trait(
-        1,
-        Range(1, 5),
-        TraitPrefixMap({"one": 1, "two": 2, "three": 3, "four": 4, "five": 5}),
-    )
-    num4 = Trait(1, Trait(1, Tuple, slow), 10)
-    num5 = Trait(1, 10, Trait(1, Tuple, slow))
+# Suppress DeprecationWarnings from TraitPrefixList and TraitPrefixMap
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class complex_value(HasTraits):
+        num1 = Trait(1, Range(1, 5), Range(-5, -1))
+        num2 = Trait(
+            1,
+            Range(1, 5),
+            TraitPrefixList("one", "two", "three", "four", "five"),
+        )
+        num3 = Trait(
+            1,
+            Range(1, 5),
+            TraitPrefixMap(
+                {"one": 1, "two": 2, "three": 3, "four": 4, "five": 5}
+            ),
+        )
+        num4 = Trait(1, Trait(1, Tuple, slow), 10)
+        num5 = Trait(1, 10, Trait(1, Tuple, slow))
 
 
 class test_complex_value(test_base2):
@@ -1065,18 +1087,6 @@ class test_list_value(test_base2):
     def test_trait_list_event(self):
         """ Record TraitListEvent behavior.
         """
-        # FIXME: The behavior of TraitListEvent is suboptimal with
-        # respect to extended slice changes. Previously, TraitListObject
-        # used to have a __setitem__() and a separate __setslice__() to
-        # handle non-extended slices. Extended slices were added to the
-        # underlying list object later. The __setitem__() code handled
-        # the new extended slices, but created the TraitListEvent in the
-        # same way it did for an integer index; namely it wrapped the
-        # value with a list. For simple slices, the `index` attribute of
-        # the TraitListEvent is an integer, and the `added` list is just
-        # the list of values added. For an extended slice, the `index`
-        # attribute is the slice object and the `added` list is the list
-        # of values wrapped in another list.
         self.obj.alist = [1, 2, 3, 4]
         self.obj.on_trait_change(self._record_trait_list_event, "alist_items")
         del self.obj.alist[0]
@@ -1089,13 +1099,16 @@ class test_list_value(test_base2):
         self.assertLastTraitListEventEqual(0, [6, 7], [4, 5])
         self.obj.alist[0:2:1] = [8, 9]
         self.assertLastTraitListEventEqual(0, [4, 5], [8, 9])
-        old_event = self.last_event
         self.obj.alist[0:2:1] = [8, 9]
-        # If no values changed, no new TraitListEvent will be generated.
+        # If list values stay the same, a new TraitListEvent will be generated.
+        self.assertLastTraitListEventEqual(0, [8, 9], [8, 9])
+        old_event = self.last_event
+        self.obj.alist[4:] = []
+        # If no structural change, NO new TraitListEvent will be generated.
         self.assertIs(self.last_event, old_event)
         self.obj.alist[0:4:2] = [10, 11]
         self.assertLastTraitListEventEqual(
-            slice(0, 4, 2), [8, 4], [10, 11]
+            slice(0, 3, 2), [8, 4], [10, 11]
         )
         del self.obj.alist[1:4:2]
         self.assertLastTraitListEventEqual(slice(1, 4, 2), [9, 5], [])
@@ -1275,3 +1288,20 @@ class ComparisonModeTests(unittest.TestCase):
         self.assertEqual(len(events), 1)
         old_compare.bar = [4, 5, 6]
         self.assertEqual(len(events), 2)
+
+
+@requires_traitsui
+class TestDeprecatedTraits(unittest.TestCase):
+
+    def test_color_deprecated(self):
+        with self.assertWarnsRegex(DeprecationWarning, "'Color' in 'traits'"):
+            Color()
+
+    def test_rgb_color_deprecated(self):
+        with self.assertWarnsRegex(DeprecationWarning,
+                                   "'RGBColor' in 'traits'"):
+            RGBColor()
+
+    def test_font_deprecated(self):
+        with self.assertWarnsRegex(DeprecationWarning, "'Font' in 'traits'"):
+            Font()
